==> pyconnectwise-0.2.4.tar.gz: pyconnectwise-0.2.4/src/pyconnectwise/endpoints/manage/CompanyManagementItSolutionsIdManagementProductsIdEndpoint.py <==
from pyconnectwise.models.base.message_model import GenericMessageModel
from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.responses.paginated_response import PaginatedResponse
from typing import Any
from pyconnectwise.models.manage.ManagementItSolutionAgreementInterfaceParameterModel import ManagementItSolutionAgreementInterfaceParameterModel

class CompanyManagementItSolutionsIdManagementProductsIdEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "{id}", parent_endpoint=parent_endpoint)
        
    
    
    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[ManagementItSolutionAgreementInterfaceParameterModel]:
        """
        Performs a GET request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagementItSolutionAgreementInterfaceParameterModel]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super().make_request(
                "GET",
                params=params
            ),
            ManagementItSolutionAgreementInterfaceParameterModel,
            self,
            page_size,
        )
    
    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a GET request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("GET", params=params).json())
        
    def put(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a PUT request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("PUT", params=params).json())
        
    def patch(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a PATCH request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("PATCH", params=params).json())
        
    def delete(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a DELETE request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("DELETE", params=params).json())

==> pyconnectwise-0.2.5.tar.gz: pyconnectwise-0.2.5/src/pyconnectwise/endpoints/manage/CompanyManagementItSolutionsIdManagementProductsIdEndpoint.py <==
from pyconnectwise.models.base.message_model import GenericMessageModel
from pyconnectwise.endpoints.base.connectwise_endpoint import ConnectWiseEndpoint
from pyconnectwise.responses.paginated_response import PaginatedResponse
from typing import Any
from pyconnectwise.models.manage.ManagementItSolutionAgreementInterfaceParameterModel import ManagementItSolutionAgreementInterfaceParameterModel

class CompanyManagementItSolutionsIdManagementProductsIdEndpoint(ConnectWiseEndpoint):
    def __init__(self, client, parent_endpoint=None):
        super().__init__(client, "{id}", parent_endpoint=parent_endpoint)
        
    
    
    def paginated(self, page: int, page_size: int, params: dict[str, int | str] = {}) -> PaginatedResponse[ManagementItSolutionAgreementInterfaceParameterModel]:
        """
        Performs a GET request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint and returns an initialized PaginatedResponse object.

        Parameters:
            page (int): The page number to request.
            page_size (int): The number of results to return per page.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            PaginatedResponse[ManagementItSolutionAgreementInterfaceParameterModel]: The initialized PaginatedResponse object.
        """
        params["page"] = page
        params["pageSize"] = page_size
        return PaginatedResponse(
            super().make_request(
                "GET",
                params=params
            ),
            ManagementItSolutionAgreementInterfaceParameterModel,
            self,
            page_size,
        )
    
    def get(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a GET request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("GET", data=data, params=params).json())
        
    def put(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a PUT request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("PUT", data=data, params=params).json())
        
    def patch(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a PATCH request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("PATCH", data=data, params=params).json())
        
    def delete(self, data: dict[str, Any] = {}, params: dict[str, int | str] = {}) -> ManagementItSolutionAgreementInterfaceParameterModel:
        """
        Performs a DELETE request against the /company/managementItSolutions/{parentId}/managementProducts/{id} endpoint.

        Parameters:
            data (dict[str, Any]): The data to send in the request body.
            params (dict[str, int | str]): The parameters to send in the request query string.
        Returns:
            ManagementItSolutionAgreementInterfaceParameterModel: The parsed response data.
        """
        return self._parse_one(ManagementItSolutionAgreementInterfaceParameterModel, super().make_request("DELETE", data=data, params=params).json())
